function [G0,G1,G2,G3,v32,v13,v21,a32,a13,a21] = odometer(C0,C1,C2,C3)
  % [G0,G1,G2,G3,v32,v13,v21,a32,a13,a21] = odometer(C0,C1,C2,C3)
  % Generate the odometer germ for a proper Descartes quadruple.

  % rotate so C1 is the youngest parent

  rotate = 0;
  while C1(1) < C2(1) || (C1(1) == C2(1) && imag(C1(2)) > imag(C2(2))) || C1(1) < C3(1) || (C1(1) == C3(1) && imag(C1(2)) > imag(C3(2)))
    [C1,C2,C3] = deal(C2,C3,C1);
    rotate = rotate + 1;
  end

  if C0(1) == 1

    % base case

    z = (C1(2)-1)/2;

    G0 = [0,0;0,imag(z)-1];
    G1 = [0,0;0,imag(z)];
    G2 = nan(2); G2(2,2) = G0(2,2);
    G3 = nan(2); G3(1,2) = G0(1,2);

    v32 = 0;
    v13 = 1;
    v21 = -1;

    a32 = 1;
    a13 = z;
    a21 = -1-z;

  else

    % induction step

    C4 = 2*(C1+C2+C3)-C0;

    [G1,G4,G2,G3,v32,v43,v24,a32,a43,a24] = odometer(C1,C4,C2,C3);

    % generate new lattice vectors

    v13 = v43 + i*v32;
    v21 = v24 - i*v32;

    a13 = a43 - i*a32;
    a21 = a24 + i*a32;

    % make room

    [G1,G2,G3,G4] = pad(G1,G2,G3,G4);

    % translate parent odometers

    G4 = G1;
    G1 = translate(G4,v32-i*v32,a32+i*a32);
    G2 = translate(G2,v32,a32);
    G5 = translate(G2,-v13+i*v13,-a13-i*a13);
    G3 = translate(G3,-i*v32,i*a32);
    G6 = translate(G3,-v21+i*v21,-a21-i*a21);

    % combine parent odometers

    G0 = G1;
    G0 = min(G0,G4-min(G4(:)-G0(:)));
    G0 = min(G0,G2-min(G2(:)-G0(:)));
    G0 = min(G0,G5-min(G5(:)-G0(:)));
    G0 = min(G0,G3-min(G3(:)-G0(:)));
    G0 = min(G0,G6-min(G6(:)-G0(:)));

    % trim output

    [G0,G1,G2,G3] = unpad(G0,G1,G2,G3);

  end

  % undo initial rotation

  while rotate
    [G1,G2,G3] = deal(G3,G1,G2);
    [v32,v13,v21] = deal(v21,v32,v13);
    [a32,a13,a21] = deal(a21,a32,a13);
    rotate = rotate - 1;
  end

end
